searchData={"items":[{"type":"module","title":"HLS","doc":"`HLS` is a simple and fast library for parsing and building HLS manifests.","ref":"HLS.html"},{"type":"module","title":"Examples - HLS","doc":"```elixir\nmaster_playlist = \"\"\"\n#EXTM3U\n#EXT-X-INDEPENDENT-SEGMENTS\n#EXT-X-STREAM-INF:PROGRAM-ID=1,BANDWIDTH=240000,RESOLUTION=396x224\nmedia.m3u8\n#EXT-X-STREAM-INF:PROGRAM-ID=1, BANDWIDTH=40000\nmedia1.m3u8\n#EXT-X-STREAM-INF:PROGRAM-ID=1,BANDWIDTH=440000,RESOLUTION=396x224\nmedia2.m3u8\n#EXT-X-STREAM-INF:PROGRAM-ID=1,BANDWIDTH=1928000,RESOLUTION=960x540\nmedia3.m3u8\n\"\"\"\n\nHLS.parse(master_playlist)\n#=> %HLS.Manifest{type: :master, variants: [%HLS.Variant{}], ...}\n```\n\nThe result of `HLS.parse/1` will be an `HLS.Manifest` struct. This struct will\ncontain all the data from the .m3u8 files, parsed into elixir data types.","ref":"HLS.html#module-examples"},{"type":"module","title":"Installation - HLS","doc":"Add `hls` to your list of dependencies in `mix.exs`.\n\n```elixir\ndef deps do\n  [\n    {:hls, \"~> 0.0.7\"}\n  ]\nend\n```","ref":"HLS.html#module-installation"},{"type":"function","title":"HLS.parse/1","doc":"Parses an HLS manifest (.m3u8) with the provided URL.\n\nThis can be the Master Playlist or a Media Playlist.","ref":"HLS.html#parse/1"},{"type":"function","title":"HLS.serialize/1","doc":"Turns a Manifest struct into its m3u8 text representation.","ref":"HLS.html#serialize/1"},{"type":"module","title":"HLS.IFrameStreamInf","doc":"","ref":"HLS.IFrameStreamInf.html"},{"type":"function","title":"HLS.IFrameStreamInf.build/1","doc":"","ref":"HLS.IFrameStreamInf.html#build/1"},{"type":"function","title":"HLS.IFrameStreamInf.serialize_attribute/2","doc":"Given a key and value, correctly serializes the attribute into \na KEY=value string, respecting the spec for which keys should\nor should not be quoted.\n\nhttps://www.rfc-editor.org/rfc/rfc8216.html#section-4.3.4.2","ref":"HLS.IFrameStreamInf.html#serialize_attribute/2"},{"type":"function","title":"HLS.IFrameStreamInf.serialize_attributes/1","doc":"","ref":"HLS.IFrameStreamInf.html#serialize_attributes/1"},{"type":"module","title":"HLS.ImageStreamInf","doc":"","ref":"HLS.ImageStreamInf.html"},{"type":"function","title":"HLS.ImageStreamInf.build/1","doc":"","ref":"HLS.ImageStreamInf.html#build/1"},{"type":"function","title":"HLS.ImageStreamInf.serialize_attribute/2","doc":"Given a key and value, correctly serializes the attribute into \na KEY=value string, respecting the spec for which keys should\nor should not be quoted.\n\nhttps://www.rfc-editor.org/rfc/rfc8216.html#section-4.3.4.2","ref":"HLS.ImageStreamInf.html#serialize_attribute/2"},{"type":"function","title":"HLS.ImageStreamInf.serialize_attributes/1","doc":"","ref":"HLS.ImageStreamInf.html#serialize_attributes/1"},{"type":"module","title":"HLS.M3ULine","doc":"Struct and functions to handle a line in the M3U8 file.","ref":"HLS.M3ULine.html"},{"type":"function","title":"HLS.M3ULine.audio_tag_line?/1","doc":"Returns true if the provided M3ULine is an audio tag.","ref":"HLS.M3ULine.html#audio_tag_line?/1"},{"type":"function","title":"HLS.M3ULine.build/1","doc":"","ref":"HLS.M3ULine.html#build/1"},{"type":"function","title":"HLS.M3ULine.get_attribute/2","doc":"Retrieves the value of the given key from the M3ULine's attributes.","ref":"HLS.M3ULine.html#get_attribute/2"},{"type":"function","title":"HLS.M3ULine.get_boolean_attribute/2","doc":"Retrieves the value of the given key from the M3ULine's attributes\nwhile ensuring the result is a boolean.","ref":"HLS.M3ULine.html#get_boolean_attribute/2"},{"type":"function","title":"HLS.M3ULine.get_float_attribute/2","doc":"Retrieves the value of the given key from the M3ULine's attributes\nwhile ensuring the result is a float","ref":"HLS.M3ULine.html#get_float_attribute/2"},{"type":"function","title":"HLS.M3ULine.get_integer_attribute/2","doc":"Retrieves the value of the given key from the M3ULine's attributes\nwhile ensuring the result is an integer","ref":"HLS.M3ULine.html#get_integer_attribute/2"},{"type":"function","title":"HLS.M3ULine.has_attribute?/3","doc":"Checks the existence of the provide key, and that it matches the provide value.","ref":"HLS.M3ULine.html#has_attribute?/3"},{"type":"function","title":"Example - HLS.M3ULine.has_attribute?/3","doc":"iex> has_attribute?(%HLS.M3ULine{}, \"noexity\", \"no\")\n    false\n\n    iex> has_attribute?(%HLS.M3ULine{attributes: %{\"KEY\" => \"VAL}}, \"key\", \"val\")\n    true","ref":"HLS.M3ULine.html#has_attribute?/3-example"},{"type":"function","title":"HLS.M3ULine.i_frame_stream_line?/1","doc":"Returns true if the provided M3ULine is an EXT-X-IMAGE-STREAM-INF tag,\n  used for trick play","ref":"HLS.M3ULine.html#i_frame_stream_line?/1"},{"type":"function","title":"HLS.M3ULine.image_stream_line?/1","doc":"Returns true if the provided M3ULine is an EXT-X-IMAGE-STREAM-INF tag,\n  used for trick play","ref":"HLS.M3ULine.html#image_stream_line?/1"},{"type":"function","title":"HLS.M3ULine.parse_resolution/2","doc":"Parses a resolution string under the given attr on the line struct. Returns a\ntuple of {width, height}, as integers.\n\nExpects a string at the given attr to look like 111x111.","ref":"HLS.M3ULine.html#parse_resolution/2"},{"type":"function","title":"HLS.M3ULine.segment_tag_line?/1","doc":"Returns true if the provided M3ULine is a segment tag.","ref":"HLS.M3ULine.html#segment_tag_line?/1"},{"type":"function","title":"HLS.M3ULine.subtitle_tag_line?/1","doc":"Returns true if the provided M3ULine is a subtitle tag.","ref":"HLS.M3ULine.html#subtitle_tag_line?/1"},{"type":"function","title":"HLS.M3ULine.uri_line?/1","doc":"Returns true if the provided M3ULine is a URI.","ref":"HLS.M3ULine.html#uri_line?/1"},{"type":"function","title":"HLS.M3ULine.variant_tag_line?/1","doc":"Returns true if the provided M3ULine is a variant tag.","ref":"HLS.M3ULine.html#variant_tag_line?/1"},{"type":"module","title":"HLS.Manifest","doc":"","ref":"HLS.Manifest.html"},{"type":"function","title":"HLS.Manifest.build/1","doc":"","ref":"HLS.Manifest.html#build/1"},{"type":"module","title":"HLS.Media","doc":"","ref":"HLS.Media.html"},{"type":"function","title":"HLS.Media.build_audio/1","doc":"","ref":"HLS.Media.html#build_audio/1"},{"type":"function","title":"HLS.Media.build_subtitle/1","doc":"","ref":"HLS.Media.html#build_subtitle/1"},{"type":"function","title":"HLS.Media.serialize_attribute/2","doc":"Given a key and value, correctly serializes the attribute into \na KEY=value string, respecting the spec for which keys should\nor should not be quoted.\n\nhttps://www.rfc-editor.org/rfc/rfc8216.html#section-4.3.4.2","ref":"HLS.Media.html#serialize_attribute/2"},{"type":"function","title":"HLS.Media.serialize_attributes/1","doc":"","ref":"HLS.Media.html#serialize_attributes/1"},{"type":"module","title":"HLS.Segment","doc":"","ref":"HLS.Segment.html"},{"type":"function","title":"HLS.Segment.build/1","doc":"","ref":"HLS.Segment.html#build/1"},{"type":"function","title":"HLS.Segment.serialize_attribute/2","doc":"Given a key and value, correctly serializes the attribute into \na KEY=value string, respecting the spec for which keys should\nor should not be quoted.\n\nhttps://www.rfc-editor.org/rfc/rfc8216.html#section-4.3.4.2","ref":"HLS.Segment.html#serialize_attribute/2"},{"type":"function","title":"HLS.Segment.serialize_attributes/1","doc":"","ref":"HLS.Segment.html#serialize_attributes/1"},{"type":"module","title":"HLS.Segment.Tiles","doc":"","ref":"HLS.Segment.Tiles.html"},{"type":"function","title":"HLS.Segment.Tiles.build/1","doc":"","ref":"HLS.Segment.Tiles.html#build/1"},{"type":"function","title":"HLS.Segment.Tiles.serialize/1","doc":"","ref":"HLS.Segment.Tiles.html#serialize/1"},{"type":"module","title":"HLS.Serializer","doc":"","ref":"HLS.Serializer.html"},{"type":"function","title":"HLS.Serializer.run/1","doc":"","ref":"HLS.Serializer.html#run/1"},{"type":"module","title":"HLS.Serializers.M3U8","doc":"","ref":"HLS.Serializers.M3U8.html"},{"type":"function","title":"HLS.Serializers.M3U8.insert_master_body/1","doc":"","ref":"HLS.Serializers.M3U8.html#insert_master_body/1"},{"type":"function","title":"HLS.Serializers.M3U8.render/1","doc":"","ref":"HLS.Serializers.M3U8.html#render/1"},{"type":"module","title":"HLS.Variant","doc":"","ref":"HLS.Variant.html"},{"type":"function","title":"HLS.Variant.build/1","doc":"","ref":"HLS.Variant.html#build/1"},{"type":"function","title":"HLS.Variant.serialize_attribute/2","doc":"Given a key and value, correctly serializes the attribute into \na KEY=value string, respecting the spec for which keys should\nor should not be quoted.\n\nhttps://www.rfc-editor.org/rfc/rfc8216.html#section-4.3.4.2","ref":"HLS.Variant.html#serialize_attribute/2"},{"type":"function","title":"HLS.Variant.serialize_attributes/1","doc":"","ref":"HLS.Variant.html#serialize_attributes/1"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}